/* 1545, Fri 12 Sep 97

   Header file for DOS implementation of CMU SNMP

   Copyright (C) 1992-1999 by Nevil Brownlee,
   ITSS Technology Development,  The University of Auckland */

/*
 * $Log: ausnmp.h,v $
 * Revision 1.1.1.1  1999/06/11 09:07:16  ipmeter
 * new
 *
 * Revision 1.1.1.1.2.2  1999/05/26 02:41:42  nevil
 * Integrate V6 and ASN code into PC versions of the meter.
 * This required a rework of the makefiles, using @cflags.opt files
 * to provide a much longer command line to the Borland C compiler.
 *
 * Revision 1.1.1.1.2.1  1999/01/08 01:38:36  nevil
 * Distribution file for 4.3b7
 *
 * Revision 1.1.1.1  1998/11/16 03:57:31  nevil
 * Import of NeTraMet 4.3b3
 *
 * Revision 1.1.1.1  1998/11/16 03:22:02  nevil
 * Import of release 4.3b3
 *
 * Revision 1.1.1.1.2.1  1998/11/11 23:14:47  nevil
 * Only include malloc.h if we HAVE_MALLOC_H
 *
 * Revision 1.1.1.1  1998/10/28 20:31:30  nevil
 * Import of NeTraMet 4.3b1
 *
 * Revision 1.1.3.2.2.2  1998/10/22 01:28:05  nevil
 * Community data wasn't being copied when PDUs were cloned, which gave
 * unpredictable results when the cloned pdu was freed.  Added code to
 * copy community data properly.  Also added PDU_MALLOC_CHECK define
 * to trace malloc() and Free() operations on pdus.
 *
 * Revision 1.1.3.2.2.1  1998/10/19 02:30:35  nevil
 * Use log_msg() to report errors instead of fprintf(stderr ..)
 *
 * Revision 1.1.3.2  1998/10/14 04:13:43  nevil
 * Merge Nicolai's patches into 4.2.1 distribution
 *
 * Revision 1.1.1.1  1998/10/13 01:35:00  nevil
 * Import of NeTraMet 4.2.1
 *
 * Revision 1.1.1.1  1998/08/24 12:09:30  nguba
 * NetraMet 4.2 Original Distribution
 *
 * Revision 1.2  1998/04/30 04:57:13  rtfm
 * Bug fixes, change copyright date
 */

#ifdef __cplusplus
extern "C" {
#endif

#ifndef EXTSNMP  /* Nevil, 29 Apr 97 */
extern int au_snmp_port;
#else
int au_snmp_port = 161;  /* Default = SNMP well-known port */
#endif

#ifndef _TYPES_H  /* From Joel's types\types.h */
typedef unsigned char Bit8;
typedef unsigned short Bit16;
typedef unsigned long Bit32;
#endif

#ifdef _AIX
#define _XOPEN_EXTENDED_SOURCE  /* Needed to get syslog defined properly */
#endif

#if defined(DOS)
#define LOG_ERR      3
#define LOG_WARNING  4
#define LOG_INFO     6
#define LOG_DEBUG    7
#else
#include <syslog.h>
#endif

#ifdef _AIX
#undef _XOPEN_EXTENDED_SOURCE
#endif

void log_msg(int priority, int die, char *fmt, ...);
   /* Generalised error message handler.  Nevil, 9 Sep 98 */

#ifdef DOS

#ifndef NULL
#define NULL ((void *)0)
#endif

#define WORDS_BIGENDIAN  0
#define SIZEOF_LONG      4

#ifndef WTCP_U_DEFS
typedef unsigned char   u_char;
typedef unsigned short  u_short;
typedef unsigned int    u_int;
typedef unsigned long   u_long;
#endif

#include <string.h>
#include <stdlib.h>
#include <mem.h>

#ifdef __FLAT__  /* Flat 32-bit memory model */

#define far
#define huge
#define farfree free
#define farmalloc malloc
#define farmove(d,s,n)  memcpy((char *)d,(char *)s,n)
#define qcmp(d,s,n)     memcmp((char *)d,(char *)s,n)

#else  /* Large memory model */
#define farmove(d,s,n)  memcpy((char *)d,(char *)s,n)
#define qcmp(d,s,n)     memcmp((char *)d,(char *)s,n)
#endif

#else  /* Not DOS */

#ifndef SUNOS
#define farmove(d,s,n)  memmove((char *)d,(char *)s,n)
#else
#define farmove(d,s,n)  memcpy((char *)d,(char *)s,n)
#endif
#define qcmp(s,d,n)     memcmp((char *)s,(char *)d,n)

#define scpos(x,y)  /* Used in TESTING code */

#define far
#define huge

#define farfree free
#define farmalloc malloc
#include <sys/types.h>
#include <string.h>
#ifdef HAVE_MALLOC_H
 #include <malloc.h>
#endif
#include <memory.h>

#endif




#ifdef __cplusplus
}           // end extern "C"
#endif
